@@ -1,5 +1,5 @@
-#%% begin initialize textsearch_ja-8.4.0-8.3.7-i586-P2
-/bin/chown postgres:pgsql /opt/postgresql-8.3.7/lib/textsearch_ja.so
+#%% begin initialize textsearch_ja-8.4.2-8.3.7-i586-P1
+/bin/chown postgres:pgsql /opt/postgresql-8.3.7/lib/libtextsearch_ja.so
 /bin/chown postgres:pgsql /opt/postgresql-8.3.7/share/contrib/textsearch_ja.sql
 /bin/chown postgres:pgsql /opt/postgresql-8.3.7/share/contrib/uninstall_textsearch_ja.sql
 /bin/chown postgres:pgsql /opt/postgresql-8.3.7/doc/contrib/README.textsearch_ja 
